@@ -2,8 +2,7 @@
 {
 if(any(is.na(pik))) stop("there are missing values in the pik vector")
 n=sum(pik)
-if(abs(n-trunc(n))<eps) n=trunc(n) 
-else stop("the sum of pik is not integer")
+n=.as_int(n)
 list = pik > eps & pik < 1 - eps
 pikb = pik[list]
 N = length(pikb)
